@@ -1,6 +1,6 @@
 /* message.c
  * Fairly general purpose message and error routines
- * Copyright (C) 1993-2003,2004,2005,2006,2007,2010,2011,2012,2014,2015,2016,2017 Olly Betts
+ * Copyright (C) 1993-2003,2004,2005,2006,2007,2010,2011,2012,2014,2015,2016,2017,2019 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,9 +49,10 @@
 # include <windows.h>
 #elif OS_UNIX
 # include <sys/types.h>
-# include <sys/stat.h>
 #endif
 
+#include <sys/stat.h>
+
 /* For funcs which want to be immune from messing around with different
  * calling conventions */
 #ifndef CDECL
@@ -888,7 +889,7 @@ msg_appname(void)
    return appname_copy;
 }
 
-int
+void
 msg_init_(char * const *argv)
 {
    char *p;
@@ -935,7 +936,7 @@ msg_init_(char * const *argv)
 	 /* On MacOS X the programs may be installed anywhere, with the
 	  * share directory and the binaries in the same directory. */
 	 p = use_path(pth, "share/survex/en.msg");
-	 if (lstat(p, &buf) == 0 && S_ISREG(buf.st_mode)) {
+	 if (stat(p, &buf) == 0 && S_ISREG(buf.st_mode)) {
 	    pth_cfg_files = use_path(pth, "share/survex");
 	    msg_macosx_relocatable = 1;
 	    goto macosx_got_msg;
@@ -947,7 +948,7 @@ msg_init_(char * const *argv)
 	  * binary, which are the ones which aven runs.
 	  */
 	 p = use_path(pth, "../Resources/en.msg");
-	 if (lstat(p, &buf) == 0 && S_ISREG(buf.st_mode)) {
+	 if (stat(p, &buf) == 0 && S_ISREG(buf.st_mode)) {
 	    pth_cfg_files = use_path(pth, "../Resources");
 	    msg_macosx_relocatable = 1;
 	    goto macosx_got_msg;
@@ -959,7 +960,7 @@ msg_init_(char * const *argv)
 	  * support files - this allows us to test binaries in the build
 	  * tree easily. */
 	 p = use_path(pth, "../lib/en.msg");
-	 if (lstat(p, &buf) == 0) {
+	 if (stat(p, &buf) == 0) {
 #ifdef S_ISREG
 	    /* POSIX way */
 	    if (S_ISREG(buf.st_mode)) {
@@ -1148,28 +1149,21 @@ macosx_got_msg:
 #endif
 
    select_charset(default_charset());
-
-   /* Return 1 if this is a relocatable install, 0 otherwise. */
-#if OS_UNIX_MACOSX
-   return msg_macosx_relocatable;
-#else
-   return OS_WIN32;
-#endif
 }
 
-#if OS_WIN32 || OS_UNIX_MACOSX
 const char *
 msg_proj_finder_(const char * file)
 {
+    struct stat sb;
     static char * r = NULL;
     static int r_len = 0;
     s_zero(&r);
     s_cat(&r, &r_len, pth_cfg_files);
     s_cat(&r, &r_len, "/proj/");
     s_cat(&r, &r_len, file);
+    if (stat(r, &sb) < 0) return NULL;
     return r;
 }
-#endif
 
 #ifndef AVEN
 /* Return message if messages available, else a fallback value. */
